﻿using PaintDotNet;
using PaintDotNet.Effects;
using System.Drawing;
using System.Windows.Forms;

namespace TileFillFromClipboard
{
    public class TileFillFromClipboardEffectPlugin : Effect
    {
        int clipBoundX;
        int clipBoundY;
        bool foundImage;
        Image clipboardImage;
        Bitmap tiledImage;
        bool mirrorVertical;
        bool mirrorHorizontal;

        public static string StaticName
        {
            get
            {
                return "Tile Fill From Clipboard";
            }
        }

        public static Bitmap StaticIcon
        {
            get
            {
                return new Bitmap(typeof(TileFillFromClipboardEffectPlugin), "EffectPluginIcon.png");
            }
        }

        public static string SubmenuName
        {
            get
            {
                return "Fill";
            }
        }

        public TileFillFromClipboardEffectPlugin()
            : base(StaticName, StaticIcon, SubmenuName, EffectFlags.Configurable)
        {
        }

        public override EffectConfigDialog CreateConfigDialog()
        {
            if (Clipboard.ContainsImage())
            {
                clipboardImage = Clipboard.GetImage();
                foundImage = true;
            }
            else
                foundImage = false;

            return new EffectPluginConfigDialog()
            {
                FoundImage = foundImage
            };
        }

        protected override void OnSetRenderInfo(EffectConfigToken parameters, RenderArgs dstArgs, RenderArgs srcArgs)
        {
            mirrorHorizontal = ((EffectPluginConfigToken)parameters).mirrorHorizontal;
            mirrorVertical = ((EffectPluginConfigToken)parameters).mirrorVertical;
            if (this.foundImage)
            {
                Rectangle selection = EnvironmentParameters.GetSelection(srcArgs.Surface.Bounds).GetBoundsInt();
                Bitmap bitmap = new Bitmap(clipboardImage);
                clipBoundX = clipboardImage.Width;
                clipBoundY = clipboardImage.Height;
                int y1 = 0;
                if (tiledImage == null)
                    tiledImage = new Bitmap(selection.Right, selection.Bottom);
                int num1 = 1;
                int num2 = 1;
                for (int y2 = selection.Top; y2 < selection.Bottom; ++y2)
                {
                    int x1 = 0;
                    if (y1 == clipBoundY)
                    {
                        if (!mirrorVertical)
                        {
                            y1 = 0;
                        }
                        else
                        {
                            num2 = -1;
                            y1 += num2;
                        }
                    }
                    if (y1 < 0)
                    {
                        y1 = 0;
                        num2 = 1;
                    }
                    for (int x2 = selection.Left; x2 < selection.Right; ++x2)
                    {
                        if (x1 == clipBoundX)
                        {
                            if (!mirrorHorizontal)
                            {
                                x1 = 0;
                            }
                            else
                            {
                                num1 = -1;
                                x1 += num1;
                            }
                        }
                        if (x1 < 0)
                        {
                            x1 = 0;
                            num1 = 1;
                        }
                        Color pixel = bitmap.GetPixel(x1, y1);
                        tiledImage.SetPixel(x2, y2, pixel);
                        x1 += num1;
                    }
                    y1 += num2;
                }
            }
            base.OnSetRenderInfo(parameters, dstArgs, srcArgs);
        }

        public override void Render(EffectConfigToken parameters, RenderArgs dstArgs, RenderArgs srcArgs, Rectangle[] rois, int startIndex, int length)
        {
            if (!foundImage)
                return;

            for (int index = startIndex; index < startIndex + length; ++index)
            {
                Rectangle rectangle = rois[index];
                for (int y = rectangle.Top; y < rectangle.Bottom; ++y)
                {
                    for (int x = rectangle.Left; x < rectangle.Right; ++x)
                    {
                        lock (tiledImage)
                            dstArgs.Surface[x, y] = tiledImage.GetPixel(x, y);
                    }
                }
            }
        }
    }
}
