﻿using PaintDotNet.Effects;
using System;
using System.Drawing;
using System.Windows.Forms;

namespace TileFillFromClipboard
{
    public class EffectPluginConfigDialog : EffectConfigDialog
    {
        private bool mirrorHorizontal;
        private bool mirrorVertical;
        private bool foundImage;
        private Button buttonOK;
        private Button btnPreview;
        private CheckBox chkMirrorVertical;
        private CheckBox chkMirrorHorizontal;
        private Panel panel1;
        private Button buttonCancel;

        public bool FoundImage
        {
            get
            {
                return this.foundImage;
            }
            set
            {
                this.foundImage = value;
                this.ToggleEnabledItems();
            }
        }

        public EffectPluginConfigDialog()
        {
            this.InitializeComponent();
        }

        private void ToggleEnabledItems()
        {
            this.chkMirrorHorizontal.Enabled = this.foundImage;
            this.chkMirrorVertical.Enabled = this.foundImage;
            this.btnPreview.Enabled = this.foundImage;
            this.buttonOK.Enabled = this.foundImage;
            if (this.foundImage)
                return;
            int num = (int)MessageBox.Show("No image was found in the Clipboard.  Before using this Effect, copy an image to the Clipboard.", "NO IMAGE FOUND", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        protected override void InitialInitToken()
        {
            this.theEffectToken = (EffectConfigToken)new EffectPluginConfigToken();
        }

        protected override void InitTokenFromDialog()
        {
            ((EffectPluginConfigToken)this.EffectToken).mirrorVertical = this.mirrorVertical;
            ((EffectPluginConfigToken)this.EffectToken).mirrorHorizontal = this.mirrorHorizontal;
        }

        protected override void InitDialogFromToken(EffectConfigToken effectToken)
        {
            EffectPluginConfigToken pluginConfigToken = (EffectPluginConfigToken)effectToken;
            this.mirrorHorizontal = pluginConfigToken.mirrorHorizontal;
            this.mirrorVertical = pluginConfigToken.mirrorVertical;
            this.chkMirrorVertical.Checked = this.mirrorVertical;
            this.chkMirrorHorizontal.Checked = this.mirrorHorizontal;
        }

        private void InitializeComponent()
        {
            this.buttonCancel = new Button();
            this.buttonOK = new Button();
            this.btnPreview = new Button();
            this.chkMirrorVertical = new CheckBox();
            this.chkMirrorHorizontal = new CheckBox();
            this.panel1 = new Panel();
            this.panel1.SuspendLayout();
            this.SuspendLayout();
            this.buttonCancel.Anchor = AnchorStyles.Bottom | AnchorStyles.Right;
            this.buttonCancel.Location = new Point(140, 20);
            this.buttonCancel.Name = "buttonCancel";
            this.buttonCancel.Size = new Size(75, 23);
            this.buttonCancel.TabIndex = 5;
            this.buttonCancel.Text = "Cancel";
            this.buttonCancel.UseVisualStyleBackColor = true;
            this.buttonCancel.Click += new EventHandler(this.buttonCancel_Click);
            this.buttonOK.Anchor = AnchorStyles.Bottom | AnchorStyles.Right;
            this.buttonOK.Location = new Point(59, 20);
            this.buttonOK.Name = "buttonOK";
            this.buttonOK.Size = new Size(75, 23);
            this.buttonOK.TabIndex = 4;
            this.buttonOK.Text = "OK";
            this.buttonOK.UseVisualStyleBackColor = true;
            this.buttonOK.Click += new EventHandler(this.buttonOK_Click);
            this.btnPreview.Location = new Point(118, 100);
            this.btnPreview.Name = "btnPreview";
            this.btnPreview.Size = new Size(75, 23);
            this.btnPreview.TabIndex = 3;
            this.btnPreview.Text = "Preview";
            this.btnPreview.UseVisualStyleBackColor = true;
            this.btnPreview.Click += new EventHandler(this.btnPreview_Click);
            this.chkMirrorVertical.AutoSize = true;
            this.chkMirrorVertical.CheckAlign = ContentAlignment.MiddleRight;
            this.chkMirrorVertical.Location = new Point(61, 28);
            this.chkMirrorVertical.Name = "chkMirrorVertical";
            this.chkMirrorVertical.Size = new Size(132, 17);
            this.chkMirrorVertical.TabIndex = 0;
            this.chkMirrorVertical.Text = "Mirror Image Vertically ";
            this.chkMirrorVertical.UseVisualStyleBackColor = true;
            this.chkMirrorVertical.CheckedChanged += new EventHandler(this.chkMirrorVertical_CheckedChanged);
            this.chkMirrorHorizontal.AutoSize = true;
            this.chkMirrorHorizontal.CheckAlign = ContentAlignment.MiddleRight;
            this.chkMirrorHorizontal.Location = new Point(52, 51);
            this.chkMirrorHorizontal.Name = "chkMirrorHorizontal";
            this.chkMirrorHorizontal.Size = new Size(141, 17);
            this.chkMirrorHorizontal.TabIndex = 1;
            this.chkMirrorHorizontal.Text = "Mirror Image Horizontally";
            this.chkMirrorHorizontal.UseVisualStyleBackColor = true;
            this.chkMirrorHorizontal.CheckedChanged += new EventHandler(this.chkMirrorHorizontal_CheckedChanged);
            this.panel1.BackColor = SystemColors.ControlLight;
            this.panel1.Controls.Add((Control)this.buttonCancel);
            this.panel1.Controls.Add((Control)this.buttonOK);
            this.panel1.Location = new Point(-22, 149);
            this.panel1.Name = "panel1";
            this.panel1.Size = new Size(335, 111);
            this.panel1.TabIndex = 8;
            this.AutoScaleDimensions = new SizeF(96f, 96f);
            this.ClientSize = new Size(227, 204);
            this.Controls.Add((Control)this.chkMirrorHorizontal);
            this.Controls.Add((Control)this.chkMirrorVertical);
            this.Controls.Add((Control)this.btnPreview);
            this.Controls.Add((Control)this.panel1);
            this.Location = new Point(0, 0);
            this.Name = "EffectPluginConfigDialog";
            this.Text = "Tile Fill From Clipboard";
            this.Controls.SetChildIndex((Control)this.panel1, 0);
            this.Controls.SetChildIndex((Control)this.btnPreview, 0);
            this.Controls.SetChildIndex((Control)this.chkMirrorVertical, 0);
            this.Controls.SetChildIndex((Control)this.chkMirrorHorizontal, 0);
            this.panel1.ResumeLayout(false);
            this.ResumeLayout(false);
            this.PerformLayout();
        }

        private void buttonOK_Click(object sender, EventArgs e)
        {
            this.FinishTokenUpdate();
            this.DialogResult = DialogResult.OK;
            this.Close();
        }

        private void buttonCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void chkMirrorVertical_CheckedChanged(object sender, EventArgs e)
        {
            this.mirrorVertical = this.chkMirrorVertical.Checked;
        }

        private void chkMirrorHorizontal_CheckedChanged(object sender, EventArgs e)
        {
            this.mirrorHorizontal = this.chkMirrorHorizontal.Checked;
        }

        private void btnPreview_Click(object sender, EventArgs e)
        {
            this.FinishTokenUpdate();
        }
    }
}
